@@ -27,9 +27,8 @@ class Plugin(ad.Plugin):
     """
 
     def on_ui_init(self, kernel):
-        from django.conf import settings
-        super(Plugin, self).on_ui_init(kernel)
-        kernel.site.makedirs_if_missing(self.get_uploads_root())
+        super().on_ui_init(kernel)
+        self.site.makedirs_if_missing(self.get_uploads_root())
 
     def get_uploads_root(self):
         # from django.conf import settings
