@@ -13,7 +13,7 @@ imgpath = Path(__file__).parent / "images"
 def objects():
     Album = rt.models.albums.Album
     File = rt.models.albums.File
-    FileUsage = rt.models.albums.FileUsage
+    # FileUsage = rt.models.albums.FileUsage
 
     demo_date = dd.demo_date()
 
@@ -48,8 +48,8 @@ FirstThereWereTen.jpg First_there_were_ten
         file = make_uploaded_file(name, imgpath / name, demo_date)
         yield File(album=thrill, file=file, description=description.replace('_', ' '))
 
-    if dd.is_installed('products'):
-        FILES = Cycler(File.objects.all())
-        OWNERS = Cycler(rt.models.products.Product.objects.all())
-        for i in range(10):
-            yield FileUsage(file=FILES.pop(), owner=OWNERS.pop())
+    # if dd.is_installed('products'):
+    #     FILES = Cycler(File.objects.all())
+    #     OWNERS = Cycler(rt.models.products.Product.objects.all())
+    #     for i in range(10):
+    #         yield FileUsage(file=FILES.pop(), owner=OWNERS.pop())
