@@ -1,7 +1,7 @@
 # Copyright 2013-2020 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""This is Lino's calendar module. See :doc:`/specs/cal`.
+"""This is Lino's calendar module. See :doc:`/plugins/cal`.
 
 .. autosummary::
    :toctree:
