@@ -17,7 +17,7 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino_xl.lib.cal']
 
     params_layout = """
-    navigation_panel
+    #navigation_panel
     user
     assigned_to
     project
@@ -54,7 +54,7 @@ class Plugin(ad.Plugin):
         for nav in self.site.models.calview.Planners.get_list_items():
             a = nav.weekly_view
             tb.add_action(a.default_action, label=nav.text,
-                instance=a.get_row_by_pk(None, "0"))
+                instance=a.get_row_by_pk(None, "0"), button_text=nav.text, icon_name=None)
 
     def setup_config_menu(self, site, user_type, m):
         mg = site.plugins.cal
