@@ -21,6 +21,9 @@ from django.utils import timezone
 from lino.core.site import has_socialauth
 
 from lino.api import dd
+
+from .choicelists import EntryStates
+
 user_mod = import_module([app for app in settings.INSTALLED_APPS if app.endswith('users')][0] + ".models")
 User = user_mod.User
 
@@ -71,31 +74,44 @@ def get_credentials(user: UserSocialAuth) -> Credentials:
 
     return creds
 
-def get_resource(user: User):
-    social_user = user.social_auth.get(provider='google')
+
+def get_resource(user: User, people: bool = False):
+    social_user = user.social_auth.filter(provider='google').first()
     creds = get_credentials(social_user)
+    if people:
+        return build('people', 'v1', credentials=creds)
     return build('calendar', 'v3', credentials=creds)
 
+
 def map_calendar_into_dbModel(cls, cal):
     calendar, _ = cls.objects.get_or_create(google_id=cal.get('id'))
-    calendar.name=cal.get('summary')
+    calendar.name=cal.get('summary', "")
     calendar.description=cal.get('description', "")
-    calendar.time_zone=cal.get('timeZone')
+    calendar.time_zone=cal.get('timeZone', 'UTC')
     return calendar
 
+
 def map_event_into_dbModel(cls, event, user_s_cal):
     e, _ = cls.objects.get_or_create(
         google_id=event['id'], google_calendar=user_s_cal.calendar)
-    e.status = event.get('status') # possible values are 'confirmed', 'tentative', 'cancelled'
+    # e.status = event.get('status') # possible values are 'confirmed', 'tentative', 'cancelled'
+    if state := EntryStates.get_by_name(event.get('status', ''), None):
+        e.state = state
     e.summary = event.get('summary', "") # The title of the event
     e.description = event.get('description', "")
     e.sequence = event.get('sequence', 0)
 
-    def resolve_datetime(stamp):
-        return timezone.make_aware(timezone.make_naive(parse(stamp)))
+    def resolve_datetime(stamp, tz=None):
+        dt = parse(stamp)
+        if timezone.is_aware(dt):
+            return dt
+        if tz is not None:
+            with timezone.override(tz):
+                return timezone.make_aware(dt)
+        return timezone.make_aware(dt)
 
-    def resolve_date_time(stamp):
-        dt = resolve_datetime(stamp)
+    def resolve_date_time(stamp, tz=None):
+        dt = resolve_datetime(stamp, tz)
         return dt.date(), dt.time()
 
     if start := event.get('start'):
@@ -126,7 +142,34 @@ def map_event_into_dbModel(cls, event, user_s_cal):
     if updated := event.get('updated'):
         e.modified = resolve_datetime(updated)
 
+    if attendees := event.get('attendees'):
+        pass
+
     return e
 
+
 def map_recurrent_event(cls, event, user_s_cal):
     pass
+
+
+def insert_calendar(cal, cal_res):
+    body = {
+        'summary': cal.name,
+        'description': cal.description,
+        'timeZone': cal.time_zone
+    }
+    c = cal_res.insert(body=body).execute()
+    cal.google_id = c.get('id')
+    cal.full_clean()
+    cal.save()
+
+
+def insert_event(event, e_res):
+    body = {
+        'summary': event.summary,
+        'description': event.description,
+        'sequence': event.sequence,
+        # 'status': event.status ; #TODO
+
+
+    }
