@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2022 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.conf import settings
@@ -10,6 +10,7 @@ from etgen.html import E
 
 from lino.api import dd, rt, _, gettext
 from lino.mixins.registrable import RegistrableState
+from lino.core.choicelists import PointingChoice, MissingRow
 
 # from lino_xl.lib.ledger.utils import DC
 from .roles import LedgerStaff
@@ -56,17 +57,6 @@ add(Credit())
 # add('C', _("Credit"), 'credit')
 
 
-class MissingAccount(object):
-    def __init__(self, common_account):
-        self.common_account = common_account
-
-    def __str__(self):
-        return _("No account pointing to {}").format(self.common_account)
-
-    def __repr__(self):
-        return "{}({})".format(self.__class__.__name__, repr(self.common_account))
-
-
 class JournalGroup(dd.Choice):
     menu_group = None
     # def __init__(self, value, text, name, menu_group=None, **kwargs):
@@ -101,12 +91,12 @@ add('10', _("Open"), 'open')
 add('20', _("Closed"), 'closed')
 
 
-class CommonAccount(dd.Choice):
+class CommonAccount(PointingChoice):
+    pointing_field_name = 'ledger.Account.common_account'
     show_values = True
     clearable = False
     needs_partner = False
     # sheet_item = ''  # filled by lino_xl.lib.sheets if installed
-    _instance = None
 
     def __init__(self, value, text, name, clearable, **kwargs):
         # the class attribute `name` ís used as value
@@ -125,20 +115,8 @@ class CommonAccount(dd.Choice):
         #     kwargs.update(sheet_item=self.sheet_item.get_object())
         # else:
         #     kwargs.pop('sheet_item', None)
-        return rt.models.ledger.Account(ref=self.value, **kwargs)
+        return self.pointing_field.model(ref=self.value, **kwargs)
 
-    def set_object(self, obj):
-        self._instance = obj
-
-    def get_object(self):
-        # return rt.models.ledger.Account.objects.get(ref=self.value)
-        if self._instance is None:
-            Account = rt.models.ledger.Account
-            try:
-                self._instance = Account.objects.get(common_account=self)
-            except Account.DoesNotExist:
-                self._instance = MissingAccount(self)
-        return self._instance
 
 
 class CommonAccounts(dd.ChoiceList):
@@ -155,7 +133,7 @@ class CommonAccounts(dd.ChoiceList):
     @dd.virtualfield(dd.ForeignKey('ledger.Account'))
     def db_object(cls, choice, ar):
         obj = choice.get_object()
-        if obj is None or isinstance(obj, MissingAccount):
+        if obj is None or isinstance(obj, MissingRow):
             return None
         return obj
 
