@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.conf import settings
@@ -17,6 +17,7 @@ from lino.modlib.printing.mixins import PrintableType, TypedPrintable
 from lino.modlib.gfks.mixins import Controllable
 from lino_xl.lib.skills.mixins import Feasible
 from lino.modlib.users.mixins import My, UserAuthored
+from lino.modlib.memo.mixins import MemoReferrable
 from lino.modlib.notify.mixins import ChangeNotifier
 from lino.modlib.uploads.mixins import UploadController
 from lino_xl.lib.outbox.mixins import MailableType, Mailable
@@ -101,11 +102,13 @@ class Note(TypedPrintable,
            ContactRelated,
            mixins.ProjectRelated,
            ChangeNotifier,
-           UploadController,
+           UploadController, MemoReferrable,
            Mailable):
 
     manager_roles_required = dd.login_required(OfficeStaff)
 
+    memo_command = "note"
+
     class Meta:
         app_label = 'notes'
         abstract = dd.is_abstract_model(__name__, 'Note')
@@ -163,7 +166,16 @@ class Note(TypedPrintable,
     def get_change_info(self, ar, cw):
         yield E.p(
             gettext("Subject"), ': ', self.subject,
-            E.br(), gettext("Client"), ': ', ar.obj2memo(self.project))
+            E.br(), gettext("Client"), ': ', self.project.obj2memo())
+
+    def obj2href(self, ar, text=None, **kwargs):
+        # if not 'title' in kwargs:
+        #     kwargs.update(title=self.summary)
+        if not text:
+            text = "#{}".format(self.id)
+        # if self.ref is not None:
+        #     return ar.obj2html(self, "#{}".format(self.ref), *args, **kwargs)
+        return ar.obj2html(self, text, **kwargs)
 
 
 
