@@ -17,7 +17,7 @@ The main purpose was to automatically have a :term:`partner` for every
    :toctree:
 
     choicelists
-    desktop
+    ui
 
 """
 
