@@ -167,7 +167,7 @@ class CheckinVisitor(NotifyingAction):
     """
     label = _("Checkin")
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
 
     required_roles = dd.login_required((OfficeUser, OfficeOperator))
     required_states = 'invited accepted present'
@@ -244,7 +244,7 @@ class ReceiveVisitor(MyVisitorAction):
     label = _("Receive")
     help_text = _("Visitor was received by agent")
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
     required_states = 'waiting'
 
     def run_from_ui(self, ar, **kw):
@@ -303,7 +303,7 @@ class CheckoutVisitor(MyVisitorAction):
     label = _("Checkout")
     help_text = _("Visitor left the centre")
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
     required_states = 'busy waiting'
 
     def run_from_ui(self, ar, **kw):
