@@ -185,7 +185,7 @@ class TicketType(mixins.BabelNamed):
 
 
 
-class Site(Referrable, ContactRelated, Starrable, DateRange):
+class Site(Referrable, ContactRelated, Starrable, DateRange, Commentable):
     # ContactRelated for backwards compatibility
     class Meta:
         app_label = 'tickets'
